nxp-pac

Crates

git

Versions

mimxrt1064

Flavors

Cr1

Struct Cr1 

#[repr(transparent)]
pub struct Cr1(pub u32);
CSI Control Register 1

Tuple Fields

0: u32

Implementations

Source

impl Cr1

pub const fn pixel_bit(&self) -> PixelBit

Pixel Bit

pub const fn set_pixel_bit(&mut self, val: PixelBit)

Pixel Bit

pub const fn redge(&self) -> Redge

Valid Pixel Clock Edge Select

pub const fn set_redge(&mut self, val: Redge)

Valid Pixel Clock Edge Select

pub const fn inv_pclk(&self) -> InvPclk

Invert Pixel Clock Input

pub const fn set_inv_pclk(&mut self, val: InvPclk)

Invert Pixel Clock Input

pub const fn inv_data(&self) -> InvData

Invert Data Input. This bit enables or disables internal inverters on the data lines.

pub const fn set_inv_data(&mut self, val: InvData)

Invert Data Input. This bit enables or disables internal inverters on the data lines.

pub const fn gclk_mode(&self) -> GclkMode

Gated Clock Mode Enable

pub const fn set_gclk_mode(&mut self, val: GclkMode)

Gated Clock Mode Enable

pub const fn clr_rxfifo(&self) -> bool

Asynchronous RXFIFO Clear

pub const fn set_clr_rxfifo(&mut self, val: bool)

Asynchronous RXFIFO Clear

pub const fn clr_statfifo(&self) -> bool

Asynchronous STATFIFO Clear

pub const fn set_clr_statfifo(&mut self, val: bool)

Asynchronous STATFIFO Clear

pub const fn pack_dir(&self) -> PackDir

Data Packing Direction

pub const fn set_pack_dir(&mut self, val: PackDir)

Data Packing Direction

pub const fn fcc(&self) -> Fcc

FIFO Clear Control

pub const fn set_fcc(&mut self, val: Fcc)

FIFO Clear Control

pub const fn ccir_en(&self) -> CcirEn

BT.656 Interface Enable. This bit selects the type of interface used.

pub const fn set_ccir_en(&mut self, val: CcirEn)

BT.656 Interface Enable. This bit selects the type of interface used.

pub const fn hsync_pol(&self) -> HsyncPol

HSYNC Polarity Select

pub const fn set_hsync_pol(&mut self, val: HsyncPol)

HSYNC Polarity Select

pub const fn sof_inten(&self) -> SofInten

Start Of Frame (SOF) Interrupt Enable. This bit enables the SOF interrupt.

pub const fn set_sof_inten(&mut self, val: SofInten)

Start Of Frame (SOF) Interrupt Enable. This bit enables the SOF interrupt.

pub const fn sof_pol(&self) -> SofPol

SOF Interrupt Polarity. This bit controls the condition that generates an SOF interrupt.

pub const fn set_sof_pol(&mut self, val: SofPol)

SOF Interrupt Polarity. This bit controls the condition that generates an SOF interrupt.

pub const fn rxff_inten(&self) -> RxffInten

RxFIFO Full Interrupt Enable. This bit enables the RxFIFO full interrupt.

pub const fn set_rxff_inten(&mut self, val: RxffInten)

RxFIFO Full Interrupt Enable. This bit enables the RxFIFO full interrupt.

pub const fn fb1_dma_done_inten(&self) -> Fb1DmaDoneInten

Frame Buffer1 DMA Transfer Done Interrupt Enable

pub const fn set_fb1_dma_done_inten(&mut self, val: Fb1DmaDoneInten)

Frame Buffer1 DMA Transfer Done Interrupt Enable

pub const fn fb2_dma_done_inten(&self) -> Fb2DmaDoneInten

Frame Buffer2 DMA Transfer Done Interrupt Enable

pub const fn set_fb2_dma_done_inten(&mut self, val: Fb2DmaDoneInten)

Frame Buffer2 DMA Transfer Done Interrupt Enable

pub const fn statff_inten(&self) -> StatffInten

STATFIFO Full Interrupt Enable. This bit enables the STAT FIFO interrupt.

pub const fn set_statff_inten(&mut self, val: StatffInten)

STATFIFO Full Interrupt Enable. This bit enables the STAT FIFO interrupt.

pub const fn sff_dma_done_inten(&self) -> SffDmaDoneInten

STATFIFO DMA Transfer Done Interrupt Enable

pub const fn set_sff_dma_done_inten(&mut self, val: SffDmaDoneInten)

STATFIFO DMA Transfer Done Interrupt Enable

pub const fn rf_or_inten(&self) -> RfOrInten

RxFIFO Overrun Interrupt Enable. This bit enables the RX FIFO overrun interrupt.

pub const fn set_rf_or_inten(&mut self, val: RfOrInten)

RxFIFO Overrun Interrupt Enable. This bit enables the RX FIFO overrun interrupt.

pub const fn sf_or_inten(&self) -> SfOrInten

STAT FIFO Overrun Interrupt Enable. This bit enables the STATFIFO overrun interrupt.

pub const fn set_sf_or_inten(&mut self, val: SfOrInten)

STAT FIFO Overrun Interrupt Enable. This bit enables the STATFIFO overrun interrupt.

pub const fn cof_int_en(&self) -> CofIntEn

Change Of Image Field (COF) Interrupt Enable

pub const fn set_cof_int_en(&mut self, val: CofIntEn)

Change Of Image Field (COF) Interrupt Enable

pub const fn ccir_mode(&self) -> CcirMode

BT

pub const fn set_ccir_mode(&mut self, val: CcirMode)

BT

pub const fn pr_p_if_en(&self) -> PrPIfEn

CSI-PrP Interface Enable

pub const fn set_pr_p_if_en(&mut self, val: PrPIfEn)

CSI-PrP Interface Enable

pub const fn eof_int_en(&self) -> EofIntEn

End-of-Frame Interrupt Enable. This bit enables and disables the EOF interrupt.

pub const fn set_eof_int_en(&mut self, val: EofIntEn)

End-of-Frame Interrupt Enable. This bit enables and disables the EOF interrupt.

pub const fn ext_vsync(&self) -> ExtVsync

External VSYNC Enable

pub const fn set_ext_vsync(&mut self, val: ExtVsync)

External VSYNC Enable

pub const fn swap16_en(&self) -> Swap16En

SWAP 16-Bit Enable

pub const fn set_swap16_en(&mut self, val: Swap16En)

SWAP 16-Bit Enable