nxp-pac

Crates

git

Versions

mimxrt1064

Flavors

Cr19

Struct Cr19 

#[repr(transparent)]
pub struct Cr19(pub u32);
CSI Control Register 19

Tuple Fields

0: u32

Implementations

Source

impl Cr19

pub const fn dma_rfifo_highest_fifo_level(&self) -> u8

This byte stores the highest FIFO level achieved by CSI FIFO timely and will be clear by writing 8’ff to it

pub const fn set_dma_rfifo_highest_fifo_level(&mut self, val: u8)

This byte stores the highest FIFO level achieved by CSI FIFO timely and will be clear by writing 8’ff to it