nxp-pac

Crates

git

Versions

mimxrt1064

Flavors

ImagPara

Struct ImagPara 

#[repr(transparent)]
pub struct ImagPara(pub u32);
CSI Image Parameter Register

Tuple Fields

0: u32

Implementations

Source

impl ImagPara

pub const fn image_height(&self) -> u16

Image Height. Indicates how many pixels in a column of the image from the sensor.

pub const fn set_image_height(&mut self, val: u16)

Image Height. Indicates how many pixels in a column of the image from the sensor.

pub const fn image_width(&self) -> u16

This field indicates the number of active pixel cycles per line

pub const fn set_image_width(&mut self, val: u16)

This field indicates the number of active pixel cycles per line