nxp-pac

Crates

git

Versions

mimxrt1064

Flavors

Sr

Struct Sr 

#[repr(transparent)]
pub struct Sr(pub u32);
CSI Status Register

Tuple Fields

0: u32

Implementations

Source

impl Sr

pub const fn drdy(&self) -> Drdy

RXFIFO Data Ready

pub const fn set_drdy(&mut self, val: Drdy)

RXFIFO Data Ready

pub const fn ecc_int(&self) -> EccInt

BT

pub const fn set_ecc_int(&mut self, val: EccInt)

BT

pub const fn hresp_err_int(&self) -> HrespErrInt

Hresponse Error Interrupt Status

pub const fn set_hresp_err_int(&mut self, val: HrespErrInt)

Hresponse Error Interrupt Status

pub const fn cof_int(&self) -> CofInt

Change Of Field Interrupt Status

pub const fn set_cof_int(&mut self, val: CofInt)

Change Of Field Interrupt Status

pub const fn f1_int(&self) -> F1Int

BT

pub const fn set_f1_int(&mut self, val: F1Int)

BT

pub const fn f2_int(&self) -> F2Int

BT

pub const fn set_f2_int(&mut self, val: F2Int)

BT

pub const fn sof_int(&self) -> SofInt

Start of Frame Interrupt Status. Indicates when SOF is detected. (Cleared by writing 1)

pub const fn set_sof_int(&mut self, val: SofInt)

Start of Frame Interrupt Status. Indicates when SOF is detected. (Cleared by writing 1)

pub const fn eof_int(&self) -> EofInt

End of Frame (EOF) Interrupt Status. Indicates when EOF is detected. (Cleared by writing 1)

pub const fn set_eof_int(&mut self, val: EofInt)

End of Frame (EOF) Interrupt Status. Indicates when EOF is detected. (Cleared by writing 1)

pub const fn rx_ff_int(&self) -> RxFfInt

RXFIFO Full Interrupt Status

pub const fn set_rx_ff_int(&mut self, val: RxFfInt)

RXFIFO Full Interrupt Status

pub const fn dma_tsf_done_fb1(&self) -> DmaTsfDoneFb1

DMA Transfer Done in Frame Buffer1

pub const fn set_dma_tsf_done_fb1(&mut self, val: DmaTsfDoneFb1)

DMA Transfer Done in Frame Buffer1

pub const fn dma_tsf_done_fb2(&self) -> DmaTsfDoneFb2

DMA Transfer Done in Frame Buffer2

pub const fn set_dma_tsf_done_fb2(&mut self, val: DmaTsfDoneFb2)

DMA Transfer Done in Frame Buffer2

pub const fn statff_int(&self) -> StatffInt

STATFIFO Full Interrupt Status

pub const fn set_statff_int(&mut self, val: StatffInt)

STATFIFO Full Interrupt Status

pub const fn dma_tsf_done_sff(&self) -> DmaTsfDoneSff

DMA Transfer Done from StatFIFO

pub const fn set_dma_tsf_done_sff(&mut self, val: DmaTsfDoneSff)

DMA Transfer Done from StatFIFO

pub const fn rf_or_int(&self) -> RfOrInt

RxFIFO Overrun Interrupt Status

pub const fn set_rf_or_int(&mut self, val: RfOrInt)

RxFIFO Overrun Interrupt Status

pub const fn sf_or_int(&self) -> SfOrInt

STATFIFO Overrun Interrupt Status

pub const fn set_sf_or_int(&mut self, val: SfOrInt)

STATFIFO Overrun Interrupt Status

pub const fn dma_field1_done(&self) -> bool

When DMA field 1 is complete, this bit will be set to 1(clear by writing 1).

pub const fn set_dma_field1_done(&mut self, val: bool)

When DMA field 1 is complete, this bit will be set to 1(clear by writing 1).

pub const fn dma_field0_done(&self) -> bool

When DMA field 0 is complete, this bit will be set to 1(clear by writing 1).

pub const fn set_dma_field0_done(&mut self, val: bool)

When DMA field 0 is complete, this bit will be set to 1(clear by writing 1).

pub const fn baseaddr_chhange_error(&self) -> bool

When using base address switching enable, this bit will be 1 when switching occur before DMA complete

pub const fn set_baseaddr_chhange_error(&mut self, val: bool)

When using base address switching enable, this bit will be 1 when switching occur before DMA complete