#[repr(transparent)]pub struct Cr1(pub u32);Expand description
CSI Control Register 1
Tuple Fields
0: u32Implementations
Sourceimpl Cr1
impl Cr1
Sourcepub const fn set_pixel_bit(&mut self, val: PixelBit)
pub const fn set_pixel_bit(&mut self, val: PixelBit)
Pixel Bit
Sourcepub const fn set_inv_pclk(&mut self, val: InvPclk)
pub const fn set_inv_pclk(&mut self, val: InvPclk)
Invert Pixel Clock Input
Sourcepub const fn inv_data(&self) -> InvData
pub const fn inv_data(&self) -> InvData
Invert Data Input. This bit enables or disables internal inverters on the data lines.
Sourcepub const fn set_inv_data(&mut self, val: InvData)
pub const fn set_inv_data(&mut self, val: InvData)
Invert Data Input. This bit enables or disables internal inverters on the data lines.
Sourcepub const fn set_gclk_mode(&mut self, val: GclkMode)
pub const fn set_gclk_mode(&mut self, val: GclkMode)
Gated Clock Mode Enable
Sourcepub const fn clr_rxfifo(&self) -> bool
pub const fn clr_rxfifo(&self) -> bool
Asynchronous RXFIFO Clear
Sourcepub const fn set_clr_rxfifo(&mut self, val: bool)
pub const fn set_clr_rxfifo(&mut self, val: bool)
Asynchronous RXFIFO Clear
Sourcepub const fn clr_statfifo(&self) -> bool
pub const fn clr_statfifo(&self) -> bool
Asynchronous STATFIFO Clear
Sourcepub const fn set_clr_statfifo(&mut self, val: bool)
pub const fn set_clr_statfifo(&mut self, val: bool)
Asynchronous STATFIFO Clear
Sourcepub const fn set_pack_dir(&mut self, val: PackDir)
pub const fn set_pack_dir(&mut self, val: PackDir)
Data Packing Direction
Sourcepub const fn ccir_en(&self) -> CcirEn
pub const fn ccir_en(&self) -> CcirEn
BT.656 Interface Enable. This bit selects the type of interface used.
Sourcepub const fn set_ccir_en(&mut self, val: CcirEn)
pub const fn set_ccir_en(&mut self, val: CcirEn)
BT.656 Interface Enable. This bit selects the type of interface used.
Sourcepub const fn set_hsync_pol(&mut self, val: HsyncPol)
pub const fn set_hsync_pol(&mut self, val: HsyncPol)
HSYNC Polarity Select
Sourcepub const fn sof_inten(&self) -> SofInten
pub const fn sof_inten(&self) -> SofInten
Start Of Frame (SOF) Interrupt Enable. This bit enables the SOF interrupt.
Sourcepub const fn set_sof_inten(&mut self, val: SofInten)
pub const fn set_sof_inten(&mut self, val: SofInten)
Start Of Frame (SOF) Interrupt Enable. This bit enables the SOF interrupt.
Sourcepub const fn sof_pol(&self) -> SofPol
pub const fn sof_pol(&self) -> SofPol
SOF Interrupt Polarity. This bit controls the condition that generates an SOF interrupt.
Sourcepub const fn set_sof_pol(&mut self, val: SofPol)
pub const fn set_sof_pol(&mut self, val: SofPol)
SOF Interrupt Polarity. This bit controls the condition that generates an SOF interrupt.
Sourcepub const fn rxff_inten(&self) -> RxffInten
pub const fn rxff_inten(&self) -> RxffInten
RxFIFO Full Interrupt Enable. This bit enables the RxFIFO full interrupt.
Sourcepub const fn set_rxff_inten(&mut self, val: RxffInten)
pub const fn set_rxff_inten(&mut self, val: RxffInten)
RxFIFO Full Interrupt Enable. This bit enables the RxFIFO full interrupt.
Sourcepub const fn fb1_dma_done_inten(&self) -> Fb1DmaDoneInten
pub const fn fb1_dma_done_inten(&self) -> Fb1DmaDoneInten
Frame Buffer1 DMA Transfer Done Interrupt Enable
Sourcepub const fn set_fb1_dma_done_inten(&mut self, val: Fb1DmaDoneInten)
pub const fn set_fb1_dma_done_inten(&mut self, val: Fb1DmaDoneInten)
Frame Buffer1 DMA Transfer Done Interrupt Enable
Sourcepub const fn fb2_dma_done_inten(&self) -> Fb2DmaDoneInten
pub const fn fb2_dma_done_inten(&self) -> Fb2DmaDoneInten
Frame Buffer2 DMA Transfer Done Interrupt Enable
Sourcepub const fn set_fb2_dma_done_inten(&mut self, val: Fb2DmaDoneInten)
pub const fn set_fb2_dma_done_inten(&mut self, val: Fb2DmaDoneInten)
Frame Buffer2 DMA Transfer Done Interrupt Enable
Sourcepub const fn statff_inten(&self) -> StatffInten
pub const fn statff_inten(&self) -> StatffInten
STATFIFO Full Interrupt Enable. This bit enables the STAT FIFO interrupt.
Sourcepub const fn set_statff_inten(&mut self, val: StatffInten)
pub const fn set_statff_inten(&mut self, val: StatffInten)
STATFIFO Full Interrupt Enable. This bit enables the STAT FIFO interrupt.
Sourcepub const fn sff_dma_done_inten(&self) -> SffDmaDoneInten
pub const fn sff_dma_done_inten(&self) -> SffDmaDoneInten
STATFIFO DMA Transfer Done Interrupt Enable
Sourcepub const fn set_sff_dma_done_inten(&mut self, val: SffDmaDoneInten)
pub const fn set_sff_dma_done_inten(&mut self, val: SffDmaDoneInten)
STATFIFO DMA Transfer Done Interrupt Enable
Sourcepub const fn rf_or_inten(&self) -> RfOrInten
pub const fn rf_or_inten(&self) -> RfOrInten
RxFIFO Overrun Interrupt Enable. This bit enables the RX FIFO overrun interrupt.
Sourcepub const fn set_rf_or_inten(&mut self, val: RfOrInten)
pub const fn set_rf_or_inten(&mut self, val: RfOrInten)
RxFIFO Overrun Interrupt Enable. This bit enables the RX FIFO overrun interrupt.
Sourcepub const fn sf_or_inten(&self) -> SfOrInten
pub const fn sf_or_inten(&self) -> SfOrInten
STAT FIFO Overrun Interrupt Enable. This bit enables the STATFIFO overrun interrupt.
Sourcepub const fn set_sf_or_inten(&mut self, val: SfOrInten)
pub const fn set_sf_or_inten(&mut self, val: SfOrInten)
STAT FIFO Overrun Interrupt Enable. This bit enables the STATFIFO overrun interrupt.
Sourcepub const fn cof_int_en(&self) -> CofIntEn
pub const fn cof_int_en(&self) -> CofIntEn
Change Of Image Field (COF) Interrupt Enable
Sourcepub const fn set_cof_int_en(&mut self, val: CofIntEn)
pub const fn set_cof_int_en(&mut self, val: CofIntEn)
Change Of Image Field (COF) Interrupt Enable
Sourcepub const fn set_ccir_mode(&mut self, val: CcirMode)
pub const fn set_ccir_mode(&mut self, val: CcirMode)
BT
Sourcepub const fn pr_p_if_en(&self) -> PrPIfEn
pub const fn pr_p_if_en(&self) -> PrPIfEn
CSI-PrP Interface Enable
Sourcepub const fn set_pr_p_if_en(&mut self, val: PrPIfEn)
pub const fn set_pr_p_if_en(&mut self, val: PrPIfEn)
CSI-PrP Interface Enable
Sourcepub const fn eof_int_en(&self) -> EofIntEn
pub const fn eof_int_en(&self) -> EofIntEn
End-of-Frame Interrupt Enable. This bit enables and disables the EOF interrupt.
Sourcepub const fn set_eof_int_en(&mut self, val: EofIntEn)
pub const fn set_eof_int_en(&mut self, val: EofIntEn)
End-of-Frame Interrupt Enable. This bit enables and disables the EOF interrupt.
Sourcepub const fn set_ext_vsync(&mut self, val: ExtVsync)
pub const fn set_ext_vsync(&mut self, val: ExtVsync)
External VSYNC Enable
Sourcepub const fn set_swap16_en(&mut self, val: Swap16En)
pub const fn set_swap16_en(&mut self, val: Swap16En)
SWAP 16-Bit Enable