#[repr(transparent)]pub struct Cr19(pub u32);Expand description
CSI Control Register 19
Tuple Fields
0: u32Implementations
Sourceimpl Cr19
impl Cr19
Sourcepub const fn dma_rfifo_highest_fifo_level(&self) -> u8
pub const fn dma_rfifo_highest_fifo_level(&self) -> u8
This byte stores the highest FIFO level achieved by CSI FIFO timely and will be clear by writing 8’ff to it
Sourcepub const fn set_dma_rfifo_highest_fifo_level(&mut self, val: u8)
pub const fn set_dma_rfifo_highest_fifo_level(&mut self, val: u8)
This byte stores the highest FIFO level achieved by CSI FIFO timely and will be clear by writing 8’ff to it