#[repr(transparent)]pub struct ImagPara(pub u32);Expand description
CSI Image Parameter Register
Tuple Fields
0: u32Implementations
Sourceimpl ImagPara
impl ImagPara
Sourcepub const fn image_height(&self) -> u16
pub const fn image_height(&self) -> u16
Image Height. Indicates how many pixels in a column of the image from the sensor.
Sourcepub const fn set_image_height(&mut self, val: u16)
pub const fn set_image_height(&mut self, val: u16)
Image Height. Indicates how many pixels in a column of the image from the sensor.
Sourcepub const fn image_width(&self) -> u16
pub const fn image_width(&self) -> u16
This field indicates the number of active pixel cycles per line
Sourcepub const fn set_image_width(&mut self, val: u16)
pub const fn set_image_width(&mut self, val: u16)
This field indicates the number of active pixel cycles per line